@@ -474,8 +474,6 @@ Container::eventFilter(QObject *s, QEvent *e)
         c1.setAlpha(100);
         QColor c2(Qt::black);
         c2.setAlpha(100);
-        QPen pen1(c1, 1);
-        QPen pen2(c2, 1);
         int cols = widget()->width() / gridX;
         int rows = widget()->height() / gridY;
         const QRect r( pe->rect() );
@@ -675,6 +673,7 @@ Container::eventFilter(QObject *s, QEvent *e)
             d->form->createContextMenu(widgetTarget, this, pos, Form::FormContextMenuTarget);
             return true;
         }
+        break;
     }
     case QEvent::Enter:
     case QEvent::Leave:
@@ -683,9 +682,9 @@ Container::eventFilter(QObject *s, QEvent *e)
         return true; // eat them
 
     default:
-        return false; // let the widget do the rest ...
+        break;
     }
-    return false;
+    return false; // let the widget do the rest ...
 }
 
 bool
@@ -746,6 +745,7 @@ Container::handleMouseReleaseEvent(QObject *s, QMouseEvent *mev)
     // cancel copying as user released Ctrl before releasing mouse button
     d->stopSelectionRectangleOrInserting();
     d->state = Private::DoingNothing;
+    d->moving.clear();
     return true; // eat
 }
 
