@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2003-2016 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2003-2017 Jarosław Staniek <staniek@kde.org>
 
    Contains code from kglobalsettings.cpp:
    Copyright (C) 2000, 2006 David Faure <faure@kde.org>
@@ -58,7 +58,10 @@
 #include <QFileDialog>
 #include <QDesktopServices>
 #include <QStyleHints>
+#include <QLineEdit>
+#include <QProcess>
 
+#include <kio_version.h>
 #include <KRun>
 #include <KToolInvocation>
 #include <KIconEffect>
@@ -235,13 +238,23 @@ QList<QMetaProperty> KexiUtils::propertiesForMetaObjectWithInherited(
     return result;
 }
 
-QStringList KexiUtils::enumKeysForProperty(const QMetaProperty& metaProperty)
+QStringList KexiUtils::enumKeysForProperty(const QMetaProperty& metaProperty, int filter)
 {
     QStringList result;
-    QMetaEnum enumerator(metaProperty.enumerator());
+    const QMetaEnum enumerator(metaProperty.enumerator());
     const int count = enumerator.keyCount();
-    for (int i = 0; i < count; i++)
-        result.append(QString::fromLatin1(enumerator.key(i)));
+    int total = 0;
+    for (int i = 0; i < count; i++) {
+        if (filter == INT_MIN) {
+            result.append(QString::fromLatin1(enumerator.key(i)));
+        } else {
+            const int v = enumerator.value(i);
+            if ((v & filter) && !(total & v)) { // !(total & v) is a protection adding against masks
+                result.append(QString::fromLatin1(enumerator.key(i)));
+                total |= v;
+            }
+        }
+    }
     return result;
 }
 
@@ -311,8 +324,11 @@ QUrl KexiUtils::getOpenImageUrl(QWidget *parent, const QString &caption, const Q
                        QImageReader::supportedMimeTypes()));
     dialog->setFileMode(QFileDialog::ExistingFile);
     dialog->setAcceptMode(QFileDialog::AcceptOpen);
-    dialog->exec();
-    return dialog->selectedUrls().value(0);
+    if (QDialog::Accepted == dialog->exec()) {
+        return dialog->selectedUrls().value(0);
+    } else {
+        return QUrl();
+    }
 }
 
 QUrl KexiUtils::getSaveImageUrl(QWidget *parent, const QString &caption, const QUrl &directory)
@@ -321,8 +337,11 @@ QUrl KexiUtils::getSaveImageUrl(QWidget *parent, const QString &caption, const Q
         getImageDialog(parent, caption.isEmpty() ? i18n("Save") : caption, directory,
                        QImageWriter::supportedMimeTypes()));
     dialog->setAcceptMode(QFileDialog::AcceptSave);
-    dialog->exec();
-    return dialog->selectedUrls().value(0);
+    if (QDialog::Accepted == dialog->exec()) {
+        return dialog->selectedUrls().value(0);
+    } else {
+        return QUrl();
+    }
 }
 
 QColor KexiUtils::blendedColors(const QColor& c1, const QColor& c2, int factor1, int factor2)
@@ -595,6 +614,7 @@ void KexiUtils::replaceColors(QPixmap* original, const QColor& color)
 void KexiUtils::replaceColors(QImage* original, const QColor& color)
 {
     Q_ASSERT(original);
+    *original = original->convertToFormat(QImage::Format_ARGB32_Premultiplied);
     QPainter p(original);
     p.setCompositionMode(QPainter::CompositionMode_SourceIn);
     p.fillRect(original->rect(), color);
@@ -748,7 +768,11 @@ tristate KexiUtils::openHyperLink(const QUrl &url, QWidget *parent, const OpenHy
 
     switch(options.tool) {
         case OpenHyperlinkOptions::DefaultHyperlinkTool:
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 31, 0)
+            return KRun::runUrl(url, type, parent, KRun::RunFlags(KRun::RunExecutables));
+#else
             return KRun::runUrl(url, type, parent);
+#endif
         case OpenHyperlinkOptions::BrowserHyperlinkTool:
             return QDesktopServices::openUrl(url);
         case OpenHyperlinkOptions::MailerHyperlinkTool:
@@ -892,14 +916,118 @@ GraphicEffects KexiUtils::graphicEffectsLevel()
     return g_graphicEffectsLevel->value;
 }
 
+#if defined Q_OS_UNIX && !defined Q_OS_MACOS
+//! For detectedDesktopSession()
+class DetectedDesktopSession
+{
+public:
+    DetectedDesktopSession() : name(detect()) {}
+    const QByteArray name;
+
+private:
+    static QByteArray detect() {
+        // https://www.freedesktop.org/software/systemd/man/pam_systemd.html#%24XDG_SESSION_DESKTOP
+        // KDE, GNOME, UNITY, LXDE, MATE, XFCE...
+        const QString xdgSessionDesktop = qgetenv("XDG_SESSION_DESKTOP").trimmed();
+        if (!xdgSessionDesktop.isEmpty()) {
+            return xdgSessionDesktop.toLatin1().toUpper();
+        }
+        // Similar to detectDesktopEnvironment() from qgenericunixservices.cpp
+        const QString xdgCurrentDesktop = qgetenv("XDG_CURRENT_DESKTOP").trimmed();
+        if (!xdgCurrentDesktop.isEmpty()) {
+            return xdgCurrentDesktop.toLatin1().toUpper();
+        }
+        // fallbacks
+        if (!qEnvironmentVariableIsEmpty("KDE_FULL_SESSION")) {
+            return QByteArrayLiteral("KDE");
+        }
+        if (!qEnvironmentVariableIsEmpty("GNOME_DESKTOP_SESSION_ID")) {
+            return QByteArrayLiteral("GNOME");
+        }
+        const QString desktopSession = qgetenv("DESKTOP_SESSION").trimmed();
+        if (desktopSession.compare("gnome", Qt::CaseInsensitive) == 0) {
+            return QByteArrayLiteral("GNOME");
+        } else if (desktopSession.compare("xfce", Qt::CaseInsensitive) == 0) {
+            return QByteArrayLiteral("XFCE");
+        }
+        return QByteArray();
+    }
+};
+
+Q_GLOBAL_STATIC(DetectedDesktopSession, s_detectedDesktopSession)
+
+QByteArray KexiUtils::detectedDesktopSession()
+{
+    return s_detectedDesktopSession->name;
+}
+
+//! @return value of XFCE property @a property for channel @a channel
+//! Sets the value pointed by @a ok to status.
+//! @todo Should be part of desktop integration or KF
+static QByteArray xfceSettingValue(const QByteArray &channel, const QByteArray &property,
+                                   bool *ok = nullptr)
+{
+    if (ok) {
+        *ok = false;
+    }
+    QByteArray result;
+    const QString command = QString::fromLatin1("xfconf-query -c \"%1\" -p \"%2\"")
+                                .arg(channel.constData())
+                                .arg(property.constData());
+    QProcess process;
+    process.start(command, QIODevice::ReadOnly | QIODevice::Text);
+    if (!process.waitForStarted()) {
+        qWarning() << "Count not execute command" << command << "error:" << process.error();
+        return QByteArray();
+    }
+    if (!process.waitForFinished() || process.exitStatus() != QProcess::NormalExit) {
+        qWarning() << "Count not finish command" << command << "error:" << process.error()
+                   << "exit status:" << process.exitStatus();
+        return QByteArray();
+    }
+    if (ok) {
+        *ok = true;
+    }
+    if (process.exitCode() == 0) {
+        result = process.readAll();
+        result.chop(1);
+    }
+    return result;  // !=0 e.g. for "no such property or channel"
+}
+
+#else
+
+QByteArray KexiUtils::detectedDesktopSession()
+{
+    return QByteArray();
+}
+#endif
+
 bool KexiUtils::activateItemsOnSingleClick(QWidget *widget)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
+    const KConfigGroup mainWindowGroup = KSharedConfig::openConfig()->group("MainWindow");
+#ifdef Q_OS_WIN
+    return mainWindowGroup.readEntry("SingleClickOpensItem", true);
+#else
+    if (mainWindowGroup.hasKey("SingleClickOpensItem")) {
+        return mainWindowGroup.readEntry("SingleClickOpensItem", true);
+    }
+    const QByteArray desktopSession = detectedDesktopSession();
+    if (desktopSession == "XFCE") {
+        /* To test:
+           Set to true: fconf-query -c xfce4-desktop -p /desktop-icons/single-click -n -t bool -s true
+           Get value: xfconf-query -c xfce4-desktop -p /desktop-icons/single-click
+           Reset: xfconf-query -c xfce4-desktop -p /desktop-icons/single-click -r
+        */
+        return xfceSettingValue("xfce4-desktop", "/desktop-icons/single-click") == "true";
+    }
+# if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
     Q_UNUSED(widget)
     return QApplication::styleHints()->singleClickActivation();
-#else
+# else
     QStyle *style = widget ? widget->style() : QApplication::style();
     return style->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick, 0, widget);
+# endif
 #endif
 }
 
@@ -1007,3 +1135,15 @@ QString KexiUtils::localizedStringToHtmlSubstring(const KLocalizedString& string
     return string.toString(Kuit::RichText)
             .remove(QLatin1String("<html>")).remove(QLatin1String("</html>"));
 }
+
+bool KexiUtils::cursorAtEnd(const QLineEdit *lineEdit)
+{
+    if (!lineEdit) {
+        return false;
+    }
+    if (lineEdit->inputMask().isEmpty()) {
+        return lineEdit->cursorPosition() >= lineEdit->displayText().length();
+    } else {
+        return lineEdit->cursorPosition() >= (lineEdit->displayText().length() - 1);
+    }
+}
