@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2003-2016 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2003-2017 Jarosław Staniek <staniek@kde.org>
 
    Contains code from kglobalsettings.h:
    Copyright (C) 2000, 2006 David Faure <faure@kde.org>
@@ -100,13 +100,13 @@ inline type findFirstChild(QObject *o, const char* className, const char* objNam
 KEXIUTILS_EXPORT QMetaProperty findPropertyWithSuperclasses(const QObject* object,
         const char* name);
 
-//! \return true is \a object object is of class name \a className
+//! \return true if \a object object is of class name \a className
 inline bool objectIsA(QObject* object, const char* className)
 {
     return 0 == qstrcmp(object->metaObject()->className(), className);
 }
 
-//! \return true is \a object object is of the class names inside \a classNames
+//! \return true if \a object object is of the class names inside \a classNames
 KEXIUTILS_EXPORT bool objectIsA(QObject* object, const QList<QByteArray>& classNames);
 
 //! \return a list of methods for \a metaObject meta object.
@@ -135,7 +135,10 @@ KEXIUTILS_EXPORT QList<QMetaProperty> propertiesForMetaObjectWithInherited(
     const QMetaObject *metaObject);
 
 //! \return a list of enum keys for meta property \a metaProperty.
-KEXIUTILS_EXPORT QStringList enumKeysForProperty(const QMetaProperty& metaProperty);
+//! If @a filter is not INT_MIN, the method only returns enum keys that overlap with filter
+//! and are not combination of other keys.
+KEXIUTILS_EXPORT QStringList enumKeysForProperty(const QMetaProperty &metaProperty,
+                                                 int filter = INT_MIN);
 
 //! Convert a list @a list of @a SourceType type to another list of @a DestinationType
 //! type using @a convertMethod function
@@ -374,6 +377,7 @@ private:
  on the current widget style. The widget also reacts on style changes. */
 class KEXIUTILS_EXPORT KTextEditorFrame : public QFrame
 {
+    Q_OBJECT
 public:
     explicit KTextEditorFrame(QWidget * parent = 0, Qt::WindowFlags f = 0);
 protected:
@@ -455,6 +459,7 @@ KEXIUTILS_EXPORT void removeRecursiveEventFilter(QObject *object, QObject *filte
     geometry it takes. */
 class KEXIUTILS_EXPORT PaintBlocker : public QObject
 {
+    Q_OBJECT
 public:
     explicit PaintBlocker(QWidget* parent);
     void setEnabled(bool set);
@@ -472,7 +477,6 @@ private:
 class KEXIUTILS_EXPORT OpenHyperlinkOptions : public QObject
 {
     Q_OBJECT
-    Q_ENUMS(HyperlinkTool)
 
 public:
 
@@ -484,6 +488,7 @@ public:
         BrowserHyperlinkTool, /*!< Opens hyperlink in a browser */
         MailerHyperlinkTool /*!< Opens hyperlink in a default mailer */
     };
+    Q_ENUM(HyperlinkTool)
 
     OpenHyperlinkOptions() :
         tool(DefaultHyperlinkTool)
@@ -565,6 +570,19 @@ inline QColor shadeBlack() { return QColor(0x232629); }
 */
 KEXIUTILS_EXPORT bool activateItemsOnSingleClick(QWidget *widget = 0);
 
+/**
+ * Detects name of desktop session based on environment variables.
+ *
+ * Possible value are like GNOME, XFCE, KDE. They are always uppercase.
+ * Following environment variables are used: XDG_SESSION_DESKTOP. XDG_CURRENT_DESKTOP,
+ * DESKTOP_SESSION, KDE_FULL_SESSION, GNOME_DESKTOP_SESSION_ID.
+ * @return empty string if no session was detected or the running OS is unsupported
+ * (Windows,
+ * macOS, non-desktop OS).
+ * @note use QApplication::styleHints() if possible.
+ */
+KEXIUTILS_EXPORT QByteArray detectedDesktopSession();
+
 /**
  * @enum CaptionFlag
  * Used to specify how to construct a window caption
