@@ -201,6 +201,8 @@ KexiDBFactory::KexiDBFactory(QObject *parent, const QVariantList &)
     // wi->setCustomTypeForProperty("pixmapData", KexiCustomPropertyFactory::PixmapData);
         wi->setCustomTypeForProperty("pixmapId", KexiCustomPropertyFactory::PixmapId);
         wi->setInternalProperty("dontStartEditingOnInserting", true);
+        wi->setSupportedAlignmentFlags(Qt::AlignLeft | Qt::AlignRight | Qt::AlignHCenter
+                                       | Qt::AlignTop | Qt::AlignBottom | Qt::AlignVCenter);
         addClass(wi);
     }
 
@@ -727,7 +729,6 @@ KexiDBFactory::isPropertyVisibleInternal(const QByteArray& classname, QWidget *w
              && property != "value";
      } else if (classname == "KexiDBLineEdit")
         ok = property != "urlDropsEnabled"
-             && property != "vAlign"
              && property != "echoMode"
              && property != "clickMessage" // Replaced by placeholderText in 2.9,
                                            // kept for backward compatibility Kexi projects created with Qt < 4.7.
@@ -781,7 +782,7 @@ KexiDBFactory::isPropertyVisibleInternal(const QByteArray& classname, QWidget *w
         ok = property != "text"; /* "text" is not needed as "caption" is used instead */
     }
     else if (classname == "KexiDBImageBox") {
-        ok = property != "font" && property != "wordbreak" && property != "pixmapId";
+        ok = property != "font" && property != "pixmapId";
     }
     else if (classname == "KexiDBCheckBox") {
         //hide text property if the widget is a child of an autofield beause there's already "caption" for this purpose
